==> biostatistics-0.0.2.tar.gz: biostatistics-0.0.2/biostats/model/__init__.py <==
from biostats.model.basic import numeral, numeral_grouped, categorical,contingency
from biostats.model.t_test import one_sample_t_test, two_sample_t_test, paired_t_test, pairwise_t_test
from biostats.model.anova import one_way_anova, two_way_anova, one_way_ancova, two_way_ancova, multivariate_anova, repeated_measures_anova
from biostats.model.exact_test import binomial_test, fisher_exact_test, mcnemar_exact_test
from biostats.model.chi_square import chi_square_test, chi_square_test_fit, mcnemar_test, mantel_haenszel_test
from biostats.model.linear_regression import correlation, correlation_matrix, simple_linear_regression, multiple_linear_regression
from biostats.model.logistic_regression import simple_logistic_regression, multiple_logistic_regression, ordered_logistic_regression, multinomial_logistic_regression
from biostats.model.non_parametric import median_test, sign_test, wilcoxon_signed_rank_test, wilcoxon_rank_sum_test, kruskal_wallis_test, friedman_test, spearman_rank_correlation
from biostats.model.others_test import screening_test, epidemiologic_study, factor_analysis, principal_component_analysis, linear_discriminant_analysis
from biostats.model.distribution_plot import histogram, density_plot, cumulative_plot, histogram_2D, density_plot_2D
from biostats.model.categorical_plot import count_plot, strip_plot, swarm_plot, box_plot, boxen_plot, violin_plot, bar_plot
from biostats.model.relational_plot import scatter_plot, line_plot, regression_plot
from biostats.model.multiple_plot import ultimate_plot, pair_plot, joint_plot
from biostats.model.others_plot import heatmap, fa_plot, pca_plot, lda_plot

==> biostatistics-0.1.1.tar.gz: biostatistics-0.1.1/biostats/model/__init__.py <==
from biostats.model.basic import numeric, numeric_grouped, categorical,contingency
from biostats.model.t_test import one_sample_t_test, two_sample_t_test, paired_t_test, pairwise_t_test
from biostats.model.anova import one_way_anova, two_way_anova, one_way_ancova, two_way_ancova, multivariate_anova, repeated_measures_anova
from biostats.model.exact_test import binomial_test, fisher_exact_test, mcnemar_exact_test
from biostats.model.chi_square import chi_square_test, chi_square_test_fit, mcnemar_test, mantel_haenszel_test
from biostats.model.linear_regression import correlation, correlation_matrix, simple_linear_regression, multiple_linear_regression
from biostats.model.logistic_regression import simple_logistic_regression, multiple_logistic_regression, ordered_logistic_regression, multinomial_logistic_regression
from biostats.model.non_parametric import median_test, sign_test, wilcoxon_signed_rank_test, wilcoxon_rank_sum_test, kruskal_wallis_test, friedman_test, spearman_rank_correlation
from biostats.model.others_test import screening_test, epidemiologic_study, factor_analysis, principal_component_analysis, linear_discriminant_analysis
from biostats.model.distribution_plot import histogram, density_plot, cumulative_plot, histogram_2D, density_plot_2D
from biostats.model.categorical_plot import count_plot, strip_plot, swarm_plot, box_plot, boxen_plot, violin_plot, bar_plot
from biostats.model.relational_plot import scatter_plot, line_plot, regression_plot
from biostats.model.multiple_plot import ultimate_plot, pair_plot, joint_plot
from biostats.model.others_plot import heatmap, fa_plot, pca_plot, lda_plot
